@@ -8,9 +8,9 @@ examples <- function(save.png=FALSE) {
   topics <- c("thermo", "examples",
     "util.array", "util.blast", "util.data", "util.expression",
     "util.fasta", "util.formula", "util.matrix", "util.misc", "util.seq", "util.units",
-    "util.water", "taxonomy", "info", "protein.info", "hkf", "water", "IAPWS95", "subcrt",
-    "makeup", "basis", "swap.basis", "species", "affinity", "equil.boltzmann", 
-    "diagram", "buffer", "nonideal", "add.protein", "protein", "ionize.aa", "yeast.aa",
+    "util.water", "taxonomy", "info", "protein.info", "hkf", "water", "IAPWS95", "subcrt", "berman",
+    "makeup", "basis", "swap.basis", "species", "affinity", "solubility", "equilibrate", 
+    "diagram", "buffer", "nonideal", "NaCl", "add.protein", "protein", "ionize.aa", "yeast.aa",
     "objective", "revisit", "EOSregress", "wjd")
   plot.it <- FALSE
   if(is.character(save.png))
@@ -27,9 +27,9 @@ examples <- function(save.png=FALSE) {
 }
 
 demos <- function(which=c("sources", "protein.equil", "affinity", "NaCl", "density", 
-  "ORP", "revisit", "findit", "ionize", "buffer", "protbuff", "yeastgfp", "mosaic",
-  "copper", "solubility", "wjd", "bugstab", "Shh", "activity_ratios",
-  "adenine", "DEW", "lambda", "TCA", "go-IU"), save.png=FALSE) {
+  "ORP", "revisit", "findit", "ionize", "buffer", "protbuff", "yeastgfp", "glycinate",
+  "mosaic", "copper", "solubility", "gold", "wjd", "bugstab", "Shh", "saturation",
+  "adenine", "DEW", "lambda", "TCA", "go-IU", "bison"), save.png=FALSE) {
   # run one or more demos from CHNOSZ with ask=FALSE, and return the value of the last one
   for(i in 1:length(which)) {
     # say something so the user sees where we are
