@@ -148,8 +148,14 @@ protein.basis <- function(protein, T=25, normalize=FALSE) {
 }
 
 protein.equil <- function(protein, T=25, loga.protein=0, digits=4) {
+  out <- character()
+  mymessage <- function(...) {
+    message(...)
+    text <- paste(list(...), collapse = " ")
+    out <<- c(out, text)
+  }
   # show the individual steps in calculating metastable equilibrium among proteins
-  message("protein.equil: temperature from argument is ", T, " degrees C")
+  mymessage("protein.equil: temperature from argument is ", T, " degrees C")
   TK <- convert(T, "K")
   # get the amino acid compositions of the proteins
   aa <- pinfo(pinfo(protein))
@@ -165,13 +171,13 @@ protein.equil <- function(protein, T=25, loga.protein=0, digits=4) {
     ionize.it <- TRUE
     iword <- "ionized"
     pH <- -thermo$basis$logact[match("H+", rownames(bmat))]
-    message("protein.equil: pH from thermo$basis is ", pH)
+    mymessage("protein.equil: pH from thermo$basis is ", pH)
   }
   # tell the user whose [Met] is in thermo$obigt
   info.Met <- info(info('[Met]', "aq"))
-  message("protein.equil: [Met] is from reference ", info.Met$ref1)
+  mymessage("protein.equil: [Met] is from reference ", info.Met$ref1)
   ## first set of output: show results of calculations for a single protein
-  message("protein.equil [1]: first protein is ", pname[1], " with length ", plength[1])
+  mymessage("protein.equil [1]: first protein is ", pname[1], " with length ", plength[1])
   # standard Gibbs energies of basis species
   G0basis <- unlist(suppressMessages(subcrt(thermo$basis$ispecies, T=T, property="G")$out))
   # coefficients of basis species in formation reactions of proteins
@@ -182,71 +188,72 @@ protein.equil <- function(protein, T=25, loga.protein=0, digits=4) {
   G0prot <- unlist(suppressMessages(subcrt(pname, T=T, property="G")$out))
   # standard Gibbs energy of formation reaction of nonionized protein, cal/mol
   G0protform <- G0prot - G0basissum
-  message("protein.equil [1]: reaction to form nonionized protein from basis species has G0(cal/mol) of ", signif(G0protform[1], digits))
+  mymessage("protein.equil [1]: reaction to form nonionized protein from basis species has G0(cal/mol) of ", signif(G0protform[1], digits))
   if(ionize.it) {
     # standard Gibbs energy of ionization of protein, cal/mol
     G0ionization <- suppressMessages(ionize.aa(aa, property="G", T=T, pH=pH))[1, ]
-    message("protein.equil [1]: ionization reaction of protein has G0(cal/mol) of ", signif(G0ionization[1], digits))
+    mymessage("protein.equil [1]: ionization reaction of protein has G0(cal/mol) of ", signif(G0ionization[1], digits))
     # standard Gibbs energy of formation reaction of ionized protein, cal/mol
     G0protform <- G0protform + G0ionization
   }
   # standard Gibbs energy of formation reaction of non/ionized residue equivalents, dimensionless
   R <- 1.9872  # gas constant, cal K^-1 mol^-1
   G0res.RT <- G0protform/R/TK/plength
-  message("protein.equil [1]: per residue, reaction to form ", iword, " protein from basis species has G0/RT of ", signif(G0res.RT[1], digits))
+  mymessage("protein.equil [1]: per residue, reaction to form ", iword, " protein from basis species has G0/RT of ", signif(G0res.RT[1], digits))
   # coefficients of basis species in formation reactions of residues
   resbasis <- suppressMessages(protein.basis(aa, T=T, normalize=TRUE))
   # logQstar and Astar/RT
   logQstar <- colSums(t(resbasis) * - thermo$basis$logact)
-  message("protein.equil [1]: per residue, logQstar is ", signif(logQstar[1], digits))
+  mymessage("protein.equil [1]: per residue, logQstar is ", signif(logQstar[1], digits))
   Astar.RT <- -G0res.RT - log(10)*logQstar
-  message("protein.equil [1]: per residue, Astar/RT = -G0/RT - 2.303logQstar is ", signif(Astar.RT[1], digits))
-  if(!is.numeric(protein)) message("protein.equil [1]: not comparing calculations with affinity() because 'protein' is not numeric")
+  mymessage("protein.equil [1]: per residue, Astar/RT = -G0/RT - 2.303logQstar is ", signif(Astar.RT[1], digits))
+  if(!is.numeric(protein)) mymessage("protein.equil [1]: not comparing calculations with affinity() because 'protein' is not numeric")
   else {
     # for **Astar** we have to set the activities of the proteins to zero, not loga.protein!
     a <- suppressMessages(affinity(iprotein=protein, T=T, loga.protein=0))
     aAstar.RT <- log(10) * as.numeric(a$values) / plength
-    message("check it!       per residue, Astar/RT calculated using affinity() is ", signif(aAstar.RT[1], digits))
+    mymessage("check it!       per residue, Astar/RT calculated using affinity() is ", signif(aAstar.RT[1], digits))
     if(!isTRUE(all.equal(Astar.RT, aAstar.RT, check.attributes=FALSE)))
       stop("Bug alert! The same value for Astar/RT cannot be calculated manually as by using affinity()")
   }
-  if(length(pname)==1) message("protein.equil [all]: all done... give me more than one protein for equilibrium calculations")
+  if(length(pname)==1) mymessage("protein.equil [all]: all done... give me more than one protein for equilibrium calculations")
   else {
     ## next set of output: equilibrium calculations
-    message("protein.equil [all]: lengths of all proteins are ", paste(plength, collapse=" "))
-    message("protein.equil [all]: Astar/RT of all residue equivalents are ", paste(signif(Astar.RT, digits), collapse=" "))
+    mymessage("protein.equil [all]: lengths of all proteins are ", paste(plength, collapse=" "))
+    mymessage("protein.equil [all]: Astar/RT of all residue equivalents are ", paste(signif(Astar.RT, digits), collapse=" "))
     expAstar.RT <- exp(Astar.RT)
     sumexpAstar.RT <- sum(expAstar.RT)
-    message("protein.equil [all]: sum of exp(Astar/RT) of all residue equivalents is ", signif(sumexpAstar.RT, digits))
+    mymessage("protein.equil [all]: sum of exp(Astar/RT) of all residue equivalents is ", signif(sumexpAstar.RT, digits))
     # boltzmann distribution
     alpha <- expAstar.RT / sumexpAstar.RT    
-    message("protein.equil [all]: equilibrium degrees of formation (alphas) of residue equivalents are ", paste(signif(alpha, digits), collapse=" "))
+    mymessage("protein.equil [all]: equilibrium degrees of formation (alphas) of residue equivalents are ", paste(signif(alpha, digits), collapse=" "))
     # check with equilibrate()
     if(is.numeric(protein)) {
       loga.equil.protein <- unlist(suppressMessages(equilibrate(a, normalize=TRUE))$loga.equil)
       # here we do have to convert from logarithms of activities of proteins to degrees of formation of residue equivalents
       a.equil.residue <- plength*10^loga.equil.protein
       ealpha <- a.equil.residue/sum(a.equil.residue)
-      message("check it!     alphas of residue equivalents from equilibrate() are ", paste(signif(ealpha, digits), collapse=" "))
+      mymessage("check it!     alphas of residue equivalents from equilibrate() are ", paste(signif(ealpha, digits), collapse=" "))
       if(!isTRUE(all.equal(alpha, ealpha, check.attributes=FALSE)))
         stop("Bug alert! The same value for alpha cannot be calculated manually as by using equilibrate()")
     }
     # total activity of residues
     loga.residue <- log10(sum(plength * 10^loga.protein))
-    message("protein.equil [all]: for activity of proteins equal to 10^", signif(loga.protein, digits), ", total activity of residues is 10^", signif(loga.residue, digits))
+    mymessage("protein.equil [all]: for activity of proteins equal to 10^", signif(loga.protein, digits), ", total activity of residues is 10^", signif(loga.residue, digits))
     # equilibrium activities of residues
     loga.residue.equil <- log10(alpha*10^loga.residue)
-    message("protein.equil [all]: log10 equilibrium activities of residue equivalents are ", paste(signif(loga.residue.equil, digits), collapse=" "))
+    mymessage("protein.equil [all]: log10 equilibrium activities of residue equivalents are ", paste(signif(loga.residue.equil, digits), collapse=" "))
     # equilibrium activities of proteins
     loga.protein.equil <- log10(10^loga.residue.equil/plength)
-    message("protein.equil [all]: log10 equilibrium activities of proteins are ", paste(signif(loga.protein.equil, digits), collapse=" "))
+    mymessage("protein.equil [all]: log10 equilibrium activities of proteins are ", paste(signif(loga.protein.equil, digits), collapse=" "))
     # check with equilibrate()
     if(is.numeric(protein)) {
       eloga.protein.equil <- unlist(suppressMessages(equilibrate(a, loga.balance=loga.residue, normalize=TRUE))$loga.equil)
-      message("check it!    log10 eq'm activities of proteins from equilibrate() are ", paste(signif(eloga.protein.equil, digits), collapse=" "))
+      mymessage("check it!    log10 eq'm activities of proteins from equilibrate() are ", paste(signif(eloga.protein.equil, digits), collapse=" "))
       if(!isTRUE(all.equal(loga.protein.equil, eloga.protein.equil, check.attributes=FALSE)))
         stop("Bug alert! The same value for log10 equilibrium activities of proteins cannot be calculated manually as by using equilibrate()")
     }
   }
+  return(out)
 }
 
