@@ -12,7 +12,7 @@
 
 subcrt <- function(species, coeff = 1, state = NULL, property = c("logK", "G", "H", "S", "V", "Cp"),
   T = seq(273.15, 623.15, 25), P = "Psat", grid = NULL, convert = TRUE, exceed.Ttr = FALSE,
-  logact = NULL, action.unbalanced = "warn", IS = 0) {
+  exceed.rhomin = FALSE, logact = NULL, action.unbalanced = "warn", IS = 0) {
 
   # revise the call if the states have 
   # come as the second argument 
@@ -51,8 +51,8 @@ subcrt <- function(species, coeff = 1, state = NULL, property = c("logK", "G", "
   # property checking
   calcprop <- property
   notprop <- property[!calcprop %in% properties]
-  if(length(notprop) > 0) stop(paste(notprop,
-    "are not valid properties\ntry rho, logK, G, H, S, V, Cp, kT, or E"))
+  if(length(notprop) == 1) stop(paste("invalid property name:", paste(notprop, collapse=" ")))
+  if(length(notprop) > 1) stop(paste("invalid property names:", paste(notprop, collapse=" ")))
   # length checking
   if(do.reaction & length(species)!=length(coeff)) 
     stop('coeff must be same length as the number of species.')
@@ -67,7 +67,12 @@ subcrt <- function(species, coeff = 1, state = NULL, property = c("logK", "G", "
   }
 
   # warn for too high temperatures for Psat 20171110
-  if(identical(P, "Psat") & any(T > 647.067)) warning("attempting calculation at P = 'Psat' for some T > Tcritical; set P = 1 (or higher)")
+  warnings <- character()
+  if(identical(P, "Psat") & any(T > 647.067)) {
+    nover <- sum(T > 647.067)
+    if(nover==1) vtext <- "value" else vtext <- "values"
+    warnings <- c(warnings, paste0("P = 'Psat' undefined for T > Tcritical (", nover, " T ", vtext, ")"))
+  }
 
   # gridding?
   do.grid <- FALSE
@@ -114,11 +119,10 @@ subcrt <- function(species, coeff = 1, state = NULL, property = c("logK", "G", "
     species <- as.character(thermo$obigt$name[ispecies])
     state <- as.character(thermo$obigt$state[ispecies])
     newstate <- as.character(thermo$obigt$state[ispecies])
-    sinfo <- ispecies
   } else {
     # from names, get species indices and states and possibly
     # keep track of phase species (cr,cr2 ...)
-    sinfo <- numeric()
+    ispecies <- numeric()
     newstate <- character()
     for(i in 1:length(species)) {
       # get the species index for a named species
@@ -134,62 +138,48 @@ subcrt <- function(species, coeff = 1, state = NULL, property = c("logK", "G", "
       if(!is.null(state[i])) is.cr <- state[i]=='cr' else is.cr <- FALSE
       if(thermo$obigt$state[si[1]]=='cr' & (is.null(state[i]) | is.cr)) {
         newstate <- c(newstate,'cr')
-        sinfo <- c(sinfo,si[1])
+        ispecies <- c(ispecies,si[1])
       } else {
         newstate <- c(newstate,as.character(thermo$obigt$state[si[1]]))
-        sinfo <- c(sinfo,si[1])
+        ispecies <- c(ispecies,si[1])
       }
     }
   }
 
-  # to make the following more readable and maybe save
-  # run time, keep some parts of thermo$obigt handy
-  ton <- thermo$obigt$name
-  tos <- thermo$obigt$state
-
-  # warn if we're running a reaction with both Berman and Helgeson minerals 20171110
-  if(do.reaction) {
-    ref1 <- thermo$obigt$ref1
-    ref2 <- thermo$obigt$ref2
-    hasHelgeson <- any(grepl("HDNB78", ref1[sinfo])) | any(grepl("HDNB78", ref2[sinfo]))
-    hasBerman <- any(tos[sinfo]=="cr_Berman")
-    if(hasHelgeson & hasBerman) warning("the reaction has minerals from both the Helgeson and Berman datasets; data may not be internally consistent")
-  }
-
   # stop if species not found
-  noname <- is.na(sinfo)
+  noname <- is.na(ispecies)
   if(TRUE %in% noname)
     stop(paste('species',species[noname],'not found.\n'))
 
   # take care of mineral phases
-  state <- as.character(tos[sinfo])
-  name <- as.character(ton[sinfo])
+  state <- as.character(thermo$obigt$state[ispecies])
+  name <- as.character(thermo$obigt$name[ispecies])
   # a counter of all species considered
-  # inpho is longer than sinfo if cr,cr2 ... phases are present
-  # sinph shows which of sinfo correspond to inpho
+  # iphases is longer than ispecies if cr,cr2 ... phases are present
+  # phasespecies shows which of ispecies correspond to iphases
   # pre-20091114: the success of this depends on there not being duplicated aqueous or other
   # non-mineral-phase species (i.e., two entries in obigt for Cu+ screw this up
   # when running the skarn example).
   # after 20091114: we can deal with duplicated species (aqueous at least)
-  inpho <- sinph <- coeff.new <- numeric()
-  for(i in 1:length(sinfo)) {
+  iphases <- phasespecies <- coeff.new <- numeric()
+  for(i in 1:length(ispecies)) {
      if(newstate[i]=='cr') {
        searchstates <- c('cr','cr2','cr3','cr4','cr5','cr6','cr7','cr8','cr9') 
-       tghs <- thermo$obigt[(ton %in% name[i]) & tos %in% searchstates,]
+       tghs <- thermo$obigt[(thermo$obigt$name %in% name[i]) & thermo$obigt$state %in% searchstates,]
        # we only take one if they are in fact duplicated species and not phase species
-       if(all(tghs$state==tghs$state[1])) tghs <- thermo$obigt[sinfo[i],]
-     } else tghs <- thermo$obigt[sinfo[i],]
-     inpho <- c(inpho,as.numeric(rownames(tghs))) 
-     sinph <- c(sinph,rep(sinfo[i],nrow(tghs)))
+       if(all(tghs$state==tghs$state[1])) tghs <- thermo$obigt[ispecies[i],]
+     } else tghs <- thermo$obigt[ispecies[i],]
+     iphases <- c(iphases,as.numeric(rownames(tghs))) 
+     phasespecies <- c(phasespecies,rep(ispecies[i],nrow(tghs)))
      coeff.new <- c(coeff.new,rep(coeff[i],nrow(tghs)))
   }
 
   # where we keep info about the species involved
-  reaction <- data.frame(coeff = coeff.new, name = ton[inpho],
-    formula = thermo$obigt$formula[inpho], state = tos[inpho],
-    ispecies = inpho, stringsAsFactors = FALSE)
+  reaction <- data.frame(coeff = coeff.new, name = thermo$obigt$name[iphases],
+    formula = thermo$obigt$formula[iphases], state = thermo$obigt$state[iphases],
+    ispecies = iphases, stringsAsFactors = FALSE)
   # make the rownames readable ... but they have to be unique
-  if(length(unique(inpho))==length(inpho)) rownames(reaction) <- as.character(inpho)
+  if(length(unique(iphases))==length(iphases)) rownames(reaction) <- as.character(iphases)
 
   # wetness etc.
   isH2O <- reaction$name=='water' & reaction$state=='liq'
@@ -215,7 +205,7 @@ subcrt <- function(species, coeff = 1, state = NULL, property = c("logK", "G", "
   # inform about unbalanced reaction
   if(do.reaction) {
     # the mass balance ... is zero for a balanced reaction
-    mss <- makeup(sinfo, coeff, sum=TRUE)
+    mss <- makeup(ispecies, coeff, sum=TRUE)
     # take out very small numbers
     mss[abs(mss) < 1e-7] <- 0
     # report and try to fix any non-zero mass balance
@@ -263,10 +253,10 @@ subcrt <- function(species, coeff = 1, state = NULL, property = c("logK", "G", "
           return(subcrt(species=newspecies, coeff=newcoeff, state=newstate,
             property=property, T=outvert(T, "K"), P=P, grid=grid, convert=convert, logact=logact, exceed.Ttr=FALSE))
         } else if(identical(action.unbalanced,'warn')) 
-            warning(paste('reaction was unbalanced, missing', as.chemical.formula(miss)),call.=FALSE)
+            warnings <- c(warnings, paste('reaction was unbalanced, missing', as.chemical.formula(miss)))
       } else {
         if(identical(action.unbalanced,'warn')) 
-          warning(paste('reaction was unbalanced, missing', as.chemical.formula(miss)),call.=FALSE)
+          warnings <- c(warnings, paste('reaction was unbalanced, missing', as.chemical.formula(miss)))
       }
     }
   }
@@ -277,45 +267,53 @@ subcrt <- function(species, coeff = 1, state = NULL, property = c("logK", "G", "
   # if logK but not G was requested, we need to calculate G
   eosprop <- calcprop
   if('logK' %in% calcprop & ! 'G' %in% calcprop) eosprop <- c(eosprop, 'G')
-  # also get g if we are dealing with mineral phases
-  if(!'G' %in% eosprop & length(inpho) > length(sinfo)) eosprop <- c(eosprop, 'G')
+  # also get G if we are dealing with mineral phases
+  if(!'G' %in% eosprop & length(iphases) > length(ispecies)) eosprop <- c(eosprop, 'G')
   # don't request logK or rho from the eos ...
   eosprop <- eosprop[!eosprop %in% c('logK','rho')]
   # the reaction result will go here
-  out <- list()
+  outprops <- list()
   # aqueous species and H2O properties
   if(TRUE %in% isaq) {
-    # 20110808 if inpho are the species indices let's avoid
-    # the overhead of info() and use new obigt2eos() instead
-    #si <- info(inpho[isaq],quiet=TRUE)
-    si <- obigt2eos(thermo$obigt[inpho[isaq],], "aq", fixGHS = TRUE)
+    # 20110808 get species parameters using obigt2eos() (faster than using info())
+    param <- obigt2eos(thermo$obigt[iphases[isaq],], "aq", fixGHS = TRUE)
     # always get density
     H2O.props <- "rho"
     # calculate A_DH and B_DH if we're using the B-dot (Helgeson) equation
-    if(any(IS != 0) & grepl("Helgeson", thermo$opt$nonideal)) H2O.props <- c(H2O.props, "A_DH", "B_DH")
+    if(any(IS != 0) & thermo$opt$nonideal %in% c("Bdot", "Bdot0", "bgamma", "bgamma0")) H2O.props <- c(H2O.props, "A_DH", "B_DH")
     # get other properties for H2O only if it's in the reaction
     if(any(isH2O)) H2O.props <- c(H2O.props, eosprop)
-    hkfstuff <- hkf(eosprop, parameters = si, T = T, P = P, H2O.props=H2O.props)
+    hkfstuff <- hkf(eosprop, parameters = param, T = T, P = P, H2O.props=H2O.props)
     p.aq <- hkfstuff$aq
     H2O.PT <- hkfstuff$H2O
+    # set properties to NA for density below 0.35 g/cm3 (a little above the critical isochore, threshold used in SUPCRT92) 20180922
+    if(!exceed.rhomin) {
+      ilowrho <- H2O.PT$rho < 350
+      ilowrho[is.na(ilowrho)] <- FALSE
+      if(any(ilowrho)) {
+        for(i in 1:length(p.aq)) p.aq[[i]][ilowrho, ] <- NA
+        if(sum(ilowrho)==1) ptext <- "pair" else ptext <- "pairs"
+        warnings <- c(warnings, paste0("below minimum density for applicability of revised HKF equations (", sum(ilowrho), " T,P ", ptext, ")"))
+      }
+    }
     # calculate activity coefficients if ionic strength is not zero
     if(any(IS != 0)) {
-      if(grepl("Helgeson", thermo$opt$nonideal)) p.aq <- nonideal(inpho[isaq], p.aq, newIS, T, P, H2O.PT$A_DH, H2O.PT$B_DH)
-      else if(thermo$opt$nonideal=="Alberty") p.aq <- nonideal(inpho[isaq], p.aq, newIS, T)
+      if(thermo$opt$nonideal %in% c("Bdot", "Bdot0", "bgamma", "bgamma0")) p.aq <- nonideal(iphases[isaq], p.aq, newIS, T, P, H2O.PT$A_DH, H2O.PT$B_DH)
+      else if(thermo$opt$nonideal=="Alberty") p.aq <- nonideal(iphases[isaq], p.aq, newIS, T)
     }
-    out <- c(out, p.aq)
+    outprops <- c(outprops, p.aq)
   } else if(any(isH2O)) {
     # we're not using the HKF, but still want water
     H2O.PT <- water(c("rho", eosprop), T = T, P = P)
   }
 
   # crystalline, gas, liquid (except water) species
-  cglstates <- c("liq", "cr", "gas", "cr2", "cr3", "cr4", "cr5", "cr6", "cr7", "cr8", "cr9", "cr_Berman")
+  cglstates <- c("liq", "cr", "gas", "cr2", "cr3", "cr4", "cr5", "cr6", "cr7", "cr8", "cr9")
   iscgl <- reaction$state %in% cglstates & reaction$name != "water"
 
   if(TRUE %in% iscgl) {
-    si <- obigt2eos(thermo$obigt[inpho[iscgl],], "cgl", fixGHS = TRUE)
-    p.cgl <- cgl(eosprop, parameters = si, T = T, P = P)
+    param <- obigt2eos(thermo$obigt[iphases[iscgl],], "cgl", fixGHS = TRUE)
+    p.cgl <- cgl(eosprop, parameters = param, T = T, P = P)
     # replace Gibbs energies with NA where the
     # phases are beyond their temperature range
     if('G' %in% eosprop) {
@@ -323,116 +321,120 @@ subcrt <- function(species, coeff = 1, state = NULL, property = c("logK", "G", "
       # 20120219 cleaned up somewhat; using exceed.Ttr and NA instead of do.phases and 999999
       # the numbers of the cgl species (becomes 0 for any that aren't cgl)
       ncgl <- iscgl
-      ncgl[iscgl] <- 1:nrow(si)
+      ncgl[iscgl] <- 1:nrow(param)
       for(i in 1:length(iscgl)) {
         # not if we're not cgl
         if(!iscgl[i]) next
         # name and state
         myname <- reaction$name[i]
         mystate <- reaction$state[i]
-        # don't proceed if the state is cr_Berman
-        if(mystate=="cr_Berman") next
-        # if this phase is cr2 or higher, check if we're below the transition temperature
-        if(!(reaction$state[i] %in% c('liq','cr','gas'))) {
-          Ttr <- Ttr(inpho[i]-1,P=P,dPdT=dPdTtr(inpho[i]-1))
-          if(all(is.na(Ttr))) next
-          if(any(T < Ttr)) {
-            status.Ttr <- "(extrapolating G)"
-            if(!exceed.Ttr) {
-              # put NA into the value of G
-              p.cgl[[ncgl[i]]]$G[T<Ttr] <- NA
-              status.Ttr <- "(using NA for G)"
-            } 
-            #message(paste('subcrt: some points below transition temperature for',myname, mystate, status.Ttr))
+        # if we are considering multiple phases, and if this phase is cr2 or higher, check if we're below the transition temperature
+        if(length(iphases) > length(ispecies) & i > 1) {
+          if(!(reaction$state[i] %in% c('liq','cr','gas')) & reaction$name[i-1] == reaction$name[i]) {
+            # after add.obigt("SUPCRT92"), quartz cr and cr2 are not next to each other in thermo$obigt,
+            # so use iphases[i-1] here, not iphases[i]-1  20181107
+            Ttr <- Ttr(iphases[i-1], iphases[i], P=P, dPdT = dPdTtr(iphases[i-1], iphases[i]))
+            if(all(is.na(Ttr))) next
+            if(any(T < Ttr)) {
+              status.Ttr <- "(extrapolating G)"
+              if(!exceed.Ttr) {
+                # put NA into the value of G
+                p.cgl[[ncgl[i]]]$G[T<Ttr] <- NA
+                status.Ttr <- "(using NA for G)"
+              } 
+              #message(paste('subcrt: some points below transition temperature for',myname, mystate, status.Ttr))
+            }
           }
         }
         # check if we're above the temperature limit or transition temperature
         # T limit (or Ttr) from the database
         warn.above <- TRUE
-        Ttr <- thermo$obigt$z.T[inpho[i]]
+        Ttr <- thermo$obigt$z.T[iphases[i]]
         # calculate Ttr at higher P if a phase transition is present
         if(i < nrow(reaction)) {
           # if the next one is cr2, cr3, etc we have a transition
-          if(reaction$state[i+1] %in% c("cr1", "cr2", "cr3", "cr4", "cr5", "cr6", "cr7", "cr8", "cr9"))
-            Ttr <- Ttr(inpho[i],P=P,dPdT=dPdTtr(inpho[i]))
-          # we don't warn here about the transition
-          warn.above <- FALSE
+          if(reaction$state[i+1] %in% c("cr1", "cr2", "cr3", "cr4", "cr5", "cr6", "cr7", "cr8", "cr9") & reaction$name[i+1] == reaction$name[i]) {
+            Ttr <- Ttr(iphases[i], iphases[i+1], P = P, dPdT = dPdTtr(iphases[i], iphases[i+1]))
+            # we don't warn here about the transition
+            warn.above <- FALSE
+          }
         }
         if(any(is.na(Ttr))) next
-        if(!all(Ttr==0) & any(T >= Ttr)) {
+        if(!all(Ttr == 0) & any(T >= Ttr)) {
           status.Ttr <- "(extrapolating G)"
           if(!exceed.Ttr) {
-            p.cgl[[ncgl[i]]]$G[T>=Ttr] <- NA
+            p.cgl[[ncgl[i]]]$G[T >= Ttr] <- NA
             status.Ttr <- "(using NA for G)"
           }
-          if(warn.above) message(paste('subcrt: some points above temperature limit for',myname, mystate, status.Ttr))
+          Tmax <- min(T[T >= Ttr])
+          if(warn.above) message(paste("subcrt: temperature(s) of", Tmax, "K and above exceed limit for", myname, mystate, status.Ttr))
         }
       }
     }
-    out <- c(out,p.cgl)
+    outprops <- c(outprops,p.cgl)
   }
 
   # water
   if(any(isH2O)) {
     p.H2O <- H2O.PT[, match(eosprop, colnames(H2O.PT)), drop=FALSE]
     p.H2O <- list(p.H2O)
-    out <- c(out, rep(p.H2O, sum(isH2O == TRUE)))
+    outprops <- c(outprops, rep(p.H2O, sum(isH2O == TRUE)))
   }
 
   # use variable-pressure standard Gibbs energy for gases
   isgas <- reaction$state %in% "gas" 
   if(any(isgas) & "G" %in% eosprop & thermo$opt$varP) {
-    for(i in which(isgas)) out[[i]]$G <- out[[i]]$G - convert(log10(P), "G", T=T)
+    for(i in which(isgas)) outprops[[i]]$G <- outprops[[i]]$G - convert(log10(P), "G", T=T)
   }
 
   # logK
   if('logK' %in% calcprop) {
-    for(i in 1:length(out)) {
-      out[[i]] <- cbind(out[[i]],data.frame(logK=convert(out[[i]]$G,'logK',T=T)))
-      colnames(out[[i]][ncol(out[[i]])]) <- 'logK'
+    for(i in 1:length(outprops)) {
+      outprops[[i]] <- cbind(outprops[[i]],data.frame(logK=convert(outprops[[i]]$G,'logK',T=T)))
+      colnames(outprops[[i]][ncol(outprops[[i]])]) <- 'logK'
     }
   }
 
   # ordering the output
-  # the indices of the species in out thus far
+  # the indices of the species in outprops thus far
   ns <- 1:nrow(reaction)
   is <- c(ns[isaq],ns[iscgl],ns[isH2O])
   if(length(ns)!=length(is)) stop('subcrt: not all species are accounted for.')
   v <- list()
-  for(i in 1:length(is))  v[[i]] <- out[[match(ns[i],is)]]
-  out <- v
+  for(i in 1:length(is))  v[[i]] <- outprops[[match(ns[i],is)]]
+  outprops <- v
 
   # deal with phases (cr,cr2) here
-  # we have to eliminate rows from out, 
+  # we have to eliminate rows from outprops, 
   # reaction and values from isaq, iscgl, isH2O
   out.new <- list()
   reaction.new <- reaction
   isaq.new <- logical()
   iscgl.new <- logical()
   isH2O.new <- logical()
-  for(i in 1:length(sinfo)) {
-    iphases <- which(sinfo[i]==sinph)
+  for(i in 1:length(ispecies)) {
+    arephases <- which(ispecies[i]==phasespecies)
     # deal with repeated species here
-    if(TRUE %in% duplicated(inpho[iphases])) {
+    if(TRUE %in% duplicated(iphases[arephases])) {
       # only take the first, not the duplicates
-      ndups <- length(which(sinfo==sinfo[i]))
-      nphases <- length(iphases) / ndups
-      iphases <- iphases[1:nphases]
+      ndups <- length(which(ispecies==ispecies[i]))
+      nphases <- length(arephases) / ndups
+      arephases <- arephases[1:nphases]
     }
-    if(length(iphases)>1) {
-      message(paste('subcrt:',length(iphases),'phases for',thermo$obigt$name[sinfo[i]],'... '), appendLF=FALSE)
+    if(length(arephases)>1) {
+      message(paste('subcrt:',length(arephases),'phases for',thermo$obigt$name[ispecies[i]],'... '), appendLF=FALSE)
       # assemble the Gibbs energies for each species
-      for(j in 1:length(iphases)) {
-        G.this <- out[[iphases[j]]]$G
+      for(j in 1:length(arephases)) {
+        G.this <- outprops[[arephases[j]]]$G
         if(length(which(is.na(G.this))) > 0 & exceed.Ttr) warning(paste('subcrt: NAs found for G of ',
-          reaction$name[iphases[j]],' ',reaction$state[iphases[j]],' at T-P point(s) ',
+          reaction$name[arephases[j]],' ',reaction$state[arephases[j]],' at T-P point(s) ',
           c2s(which(is.na(G.this)),sep=' '),sep=''),call.=FALSE)
         if(j==1) G <- as.data.frame(G.this)
         else G <- cbind(G,as.data.frame(G.this))
       }
       # find the minimum-energy phase at each T-P point
       phasestate <- numeric()
-      out.new.entry <- out[[1]]
+      out.new.entry <- outprops[[arephases[1]]]
       for(j in 1:nrow(G)) {
         ps <- which.min(as.numeric(G[j,]))
         if(length(ps)==0) {
@@ -441,58 +443,56 @@ subcrt <- function(species, coeff = 1, state = NULL, property = c("logK", "G", "
           #ps <- 1
           # - above temperature limit for the highest-T phase (subcrt.Rd skarn example) --> use highest-T phase 20171110
           ps <- ncol(G)
-          if(exceed.Ttr) warning('subcrt: stable phase for ',reaction$name[iphases[ps]],' at T-P point ',j,
-          ' undetermined (using ',reaction$state[iphases[ps]],')',call.=FALSE)
+          if(exceed.Ttr) warning('subcrt: stable phase for ',reaction$name[arephases[ps]],' at T-P point ',j,
+          ' undetermined (using ',reaction$state[arephases[ps]],')',call.=FALSE)
         } 
         phasestate <- c(phasestate,ps)
-        out.new.entry[j,] <- out[[ iphases[ps] ]][j,]
+        out.new.entry[j,] <- outprops[[ arephases[ps] ]][j,]
       }
 
       # update our objects
       out.new[[i]] <- cbind(out.new.entry,data.frame(polymorph=phasestate))
-      reaction.new[i,] <- reaction[iphases[phasestate[1]],]
+      reaction.new[i,] <- reaction[arephases[phasestate[1]],]
       # mark the minerals with multiple phases
-      rs <- as.character(reaction.new$state)
-      rs[i] <- 'cr*'
-      reaction.new$state <- rs
-      isaq.new <- c(isaq.new,isaq[iphases[phasestate[1]]])
-      iscgl.new <- c(iscgl.new,iscgl[iphases[phasestate[1]]])
-      isH2O.new <- c(isH2O.new,isH2O[iphases[phasestate[1]]])
+      reaction.new$state[i] <- "cr*"
+      isaq.new <- c(isaq.new,isaq[arephases[phasestate[1]]])
+      iscgl.new <- c(iscgl.new,iscgl[arephases[phasestate[1]]])
+      isH2O.new <- c(isH2O.new,isH2O[arephases[phasestate[1]]])
       # info for the user
       up <- unique(phasestate)
       if(length(up)>1) { word <- 'are'; p.word <- 'phases' }
       else { word <- 'is'; p.word <- 'phase' }
-      message(paste(p.word,c2s(unique(phasestate)),word,'stable'))
+      message(paste(p.word,paste(unique(phasestate), collapse=","),word,'stable'))
     } else {
       # multiple phases aren't involved ... things stay the same
-      out.new[[i]] <- out[[iphases]]
-      # hmm.. this could mess up our coefficients 20091103
-      #reaction.new[i,] <- reaction[iphases,]
-      coeff.orig <- reaction$coeff
-      reaction.new[i,] <- reaction[iphases,]
-      reaction.new$coeff <- coeff.orig
-      rs <- as.character(reaction.new$state)
-      rs[i] <- as.character(reaction$state[iphases])
-      reaction.new$state <- rs
-      isaq.new <- c(isaq.new,isaq[iphases])
-      iscgl.new <- c(iscgl.new,iscgl[iphases])
-      isH2O.new <- c(isH2O.new,isH2O[iphases])
+      out.new[[i]] <- outprops[[arephases]]
+      reaction.new[i, ] <- reaction[arephases, ]
+      reaction.new$state[i] <- reaction$state[arephases]
+      isaq.new <- c(isaq.new,isaq[arephases])
+      iscgl.new <- c(iscgl.new,iscgl[arephases])
+      isH2O.new <- c(isH2O.new,isH2O[arephases])
     }
   }
-  out <- out.new
-  reaction <- reaction.new[1:length(sinfo),]
+
+  outprops <- out.new
+  # remove the rows that were added to keep track of phase transitions
+  reaction <- reaction.new[1:length(ispecies),]
+  # the manipulations above should get the correct species indices and state labels,
+  # but if species are (intentionally) repeated, include only the first
+  # (and possibly incorrect) reaction coefficients, so use the originals here 20180822
+  reaction$coeff <- coeff
   isaq <- isaq.new
   iscgl <- iscgl.new
   isH2O <- isH2O.new
 
   # adjust the output order of the properties
-  for(i in 1:length(out)) {
+  for(i in 1:length(outprops)) {
     # the calculated properties are first
-    ipp <- match(calcprop, colnames(out[[i]]))
+    ipp <- match(calcprop, colnames(outprops[[i]]))
     # move polymorph/loggam columns to end
-    if('polymorph' %in% colnames(out[[i]])) ipp <- c(ipp,match('polymorph',colnames(out[[i]]))) 
-    if('loggam' %in% colnames(out[[i]])) ipp <- c(ipp,match('loggam',colnames(out[[i]]))) 
-    out[[i]] <- out[[i]][,ipp,drop=FALSE]
+    if('polymorph' %in% colnames(outprops[[i]])) ipp <- c(ipp,match('polymorph',colnames(outprops[[i]]))) 
+    if('loggam' %in% colnames(outprops[[i]])) ipp <- c(ipp,match('loggam',colnames(outprops[[i]]))) 
+    outprops[[i]] <- outprops[[i]][,ipp,drop=FALSE]
   }
 
   # add up reaction properties
@@ -503,7 +503,7 @@ subcrt <- function(species, coeff = 1, state = NULL, property = c("logK", "G", "
     if(!is.null(logact)) {
       logQ <- logK <- rep(0,length(T))
       for(i in 1:length(coeff)) {
-        logK <- logK + out[[i]]$logK * coeff[i]
+        logK <- logK + outprops[[i]]$logK * coeff[i]
         logQ <- logQ + logact[i] * coeff[i]
       }
       reaction <- cbind(reaction,logact)
@@ -515,15 +515,15 @@ subcrt <- function(species, coeff = 1, state = NULL, property = c("logK", "G", "
     # loop over reaction coefficients
     for(i in 1:length(coeff)) {
       # assemble polymorph columns separately
-      if('polymorph' %in% colnames(out[[i]])) {
-         sc <- as.data.frame(out[[i]]$polymorph)
-         out[[i]] <- out[[i]][,-match('polymorph',colnames(out[[i]]))]
+      if('polymorph' %in% colnames(outprops[[i]])) {
+         sc <- as.data.frame(outprops[[i]]$polymorph)
+         outprops[[i]] <- outprops[[i]][,-match('polymorph',colnames(outprops[[i]]))]
          colnames(sc) <- as.character(reaction$name[i])
          if(is.null(morphcols)) morphcols <- sc
          else morphcols <- cbind(morphcols,sc)
       }
       # include a zero loggam column if needed (for those species that are ideal)
-      o.i <- out[[i]]
+      o.i <- outprops[[i]]
       if('loggam' %in% colnames(o.i)) if(!'loggam' %in% colnames(o))
         o <- cbind(o,loggam=0)
       if('loggam' %in% colnames(o)) if(!'loggam' %in% colnames(o.i))
@@ -532,18 +532,18 @@ subcrt <- function(species, coeff = 1, state = NULL, property = c("logK", "G", "
       o <- o + o.i * coeff[i]
     }
     # output for reaction (stack on polymorph columns if exist)
-    if(!is.null(morphcols)) out <- list(reaction=reaction,out=o,polymorphs=morphcols)
-    else out <- list(reaction=reaction,out=o)
+    if(!is.null(morphcols)) OUT <- list(reaction=reaction,out=o,polymorphs=morphcols)
+    else OUT <- list(reaction=reaction,out=o)
   } else {
     # output for species: strip the coeff column from reaction
     reaction <- reaction[,-match('coeff',colnames(reaction))]
-    out <- c(list(species=reaction),out)
+    OUT <- c(list(species=reaction),outprops)
   }
   # append T,P,rho, A, logQ columns and convert units
-  for(i in 2:length(out)) {
+  for(i in 2:length(OUT)) {
     # affinity and logQ
     if(i==2) if(do.reaction & !is.null(logact)) {
-      out[[i]] <- cbind(out[[i]],data.frame(logQ=logQ,A=A))
+      OUT[[i]] <- cbind(OUT[[i]],data.frame(logQ=logQ,A=A))
     }
     # 20120114 only prepend T, P, rho columns if we have more than one T
     # 20171020 or if the 'property' argument is missing (it's nice to see everything using e.g. subcrt("H2O", T=150))
@@ -555,27 +555,32 @@ subcrt <- function(species, coeff = 1, state = NULL, property = c("logK", "G", "
       # try to stuff in a column of rho if we have aqueous species
       # watch out! supcrt-ish densities are in g/cc not kg/m3
       if('rho' %in% calcprop | ( (missing(property) | identical(property, c("logK", "G", "H", "S", "V", "Cp"))) &
-                                any(c(isaq,isH2O))) & (names(out)[i])!='polymorph') 
-        out[[i]] <- cbind(data.frame(T=T.out,P=P.out,rho=H2O.PT$rho/1000),out[[i]])
+                                any(c(isaq,isH2O))) & (names(OUT)[i])!='polymorph') 
+        OUT[[i]] <- cbind(data.frame(T=T.out,P=P.out,rho=H2O.PT$rho/1000),OUT[[i]])
       else
-        out[[i]] <- cbind(data.frame(T=T.out,P=P.out,out[[i]]))
+        OUT[[i]] <- cbind(data.frame(T=T.out,P=P.out,OUT[[i]]))
     }
     if(convert) {
-      for(j in 1:ncol(out[[i]])) {
-        if(colnames(out[[i]])[j] %in% c('G','H','S','Cp')) out[[i]][,j] <- outvert(out[[i]][,j],'cal')
+      for(j in 1:ncol(OUT[[i]])) {
+        if(colnames(OUT[[i]])[j] %in% c('G','H','S','Cp')) OUT[[i]][,j] <- outvert(OUT[[i]][,j],'cal')
       }
     }
   }
   # put ionic strength next to any loggam columns
-  for(i in 2:length(out)) {
-    if('loggam' %in% colnames(out[[i]])) out[[i]] <- cbind(out[[i]],IS=newIS)
+  for(i in 2:length(OUT)) {
+    if('loggam' %in% colnames(OUT[[i]])) OUT[[i]] <- cbind(OUT[[i]],IS=newIS)
   }
   # more fanagling for species
   if(!do.reaction) {
-    out <- list(species=out$species,out=out[2:length(out)])
+    OUT <- list(species=OUT$species, out=OUT[2:length(OUT)])
     # add names to the output
-    names(out$out) <- as.character(reaction$name)
+    names(OUT$out) <- as.character(reaction$name)
   }
-  return(out)
+  # add warnings to output 20180922
+  if(length(warnings) > 0) {
+    OUT <- c(OUT, list(warnings=warnings))
+    for(warn in warnings) warning(warn)
+  }
+  return(OUT)
 }
 
